@@ -259,7 +259,7 @@ sub _objSearch
         }
 
         # entries below suffix
-        if ($pkey && defined($oconf->{container}) && !defined($oconf->{container}[0]->{rdn})) {
+        if (defined($pkey) && defined($oconf->{container}) && !defined($oconf->{container}[0]->{rdn})) {
             my $poconf = $self->{object}{$oconf->{container}[0]->{oname}[0]}->{conf};
 
             if ($oconf->{table}[0] ne $poconf->{table}[0]) {
